package
Version:
v0.0.0-...-39e63cc
Opens a new window with list of versions in this module.
Published: Feb 10, 2024
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func AuthToken(apiKey, requestToken string)
type Session struct {
Session struct {
Name string `json:"name"`
Key string `json:"key"`
Subscriber int `json:"subscriber"`
} `json:"session"`
}
type Token struct {
Token string `json:"token"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.